@@ -7,4 +7,4 @@ fi
 #---------------------------#
 # run the program           #
 #---------------------------#
-java -cp ${JTS_LIB_DIR}/JTSTestBuilder.jar org.locationtech.jtstest.cmd.JTSOpCmd $@
+java -cp ${JTS_LIB_DIR}/JTSTestBuilder.jar org.locationtech.jtstest.cmd.JTSOpCmd "$@"
