@@ -11,7 +11,12 @@
  */
 package org.locationtech.jtstest.function;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Map;
+import java.util.Set;
+import java.util.TreeMap;
+import java.util.TreeSet;
 
 public class DoubleKeyMap 
 {
