@@ -28,6 +28,7 @@ import org.locationtech.jtstest.function.BufferByUnionFunctions;
 import org.locationtech.jtstest.function.BufferFunctions;
 import org.locationtech.jtstest.function.ConstructionFunctions;
 import org.locationtech.jtstest.function.ConversionFunctions;
+import org.locationtech.jtstest.function.CoverageFunctions;
 import org.locationtech.jtstest.function.CreateFractalShapeFunctions;
 import org.locationtech.jtstest.function.CreateRandomShapeFunctions;
 import org.locationtech.jtstest.function.CreateShapeFunctions;
@@ -44,6 +45,7 @@ import org.locationtech.jtstest.function.LineSegmentFunctions;
 import org.locationtech.jtstest.function.LinearReferencingFunctions;
 import org.locationtech.jtstest.function.NodingFunctions;
 import org.locationtech.jtstest.function.OffsetCurveFunctions;
+import org.locationtech.jtstest.function.OrientationFPFunctions;
 import org.locationtech.jtstest.function.OrientationFunctions;
 import org.locationtech.jtstest.function.OverlayFunctions;
 import org.locationtech.jtstest.function.OverlayNGFunctions;
@@ -60,11 +62,13 @@ import org.locationtech.jtstest.function.PolygonizeFunctions;
 import org.locationtech.jtstest.function.PrecisionFunctions;
 import org.locationtech.jtstest.function.PreparedGeometryFunctions;
 import org.locationtech.jtstest.function.SelectionFunctions;
+import org.locationtech.jtstest.function.SelectionNGFunctions;
 import org.locationtech.jtstest.function.SimplificationFunctions;
 import org.locationtech.jtstest.function.SnappingFunctions;
 import org.locationtech.jtstest.function.SortingFunctions;
 import org.locationtech.jtstest.function.SpatialIndexFunctions;
 import org.locationtech.jtstest.function.SpatialPredicateFunctions;
+import org.locationtech.jtstest.function.SpatialPredicateNGFunctions;
 import org.locationtech.jtstest.function.TriangleFunctions;
 import org.locationtech.jtstest.function.TriangulatePolyFunctions;
 import org.locationtech.jtstest.function.TriangulationFunctions;
@@ -91,6 +95,7 @@ public class GeometryFunctionRegistry
     funcRegistry.add(BufferByUnionFunctions.class);
     funcRegistry.add(ConstructionFunctions.class);
     funcRegistry.add(ConversionFunctions.class);
+    funcRegistry.add(CoverageFunctions.class);
     funcRegistry.add(EditFunctions.class);
     funcRegistry.add(HullFunctions.class);
     funcRegistry.add(LinearReferencingFunctions.class);
@@ -100,6 +105,7 @@ public class GeometryFunctionRegistry
     funcRegistry.add(PrecisionFunctions.class);
     funcRegistry.add(PreparedGeometryFunctions.class);
     funcRegistry.add(SelectionFunctions.class);
+    funcRegistry.add(SelectionNGFunctions.class);
     funcRegistry.add(SimplificationFunctions.class);
     funcRegistry.add(AffineTransformationFunctions.class);
     funcRegistry.add(DiffFunctions.class);
@@ -110,10 +116,12 @@ public class GeometryFunctionRegistry
     funcRegistry.add(CreateRandomShapeFunctions.class);
     funcRegistry.add(SpatialIndexFunctions.class);
     funcRegistry.add(SpatialPredicateFunctions.class);
+    funcRegistry.add(SpatialPredicateNGFunctions.class);
     funcRegistry.add(JTSFunctions.class);
     //funcRegistry.add(MemoryFunctions.class);
     funcRegistry.add(OffsetCurveFunctions.class);
     funcRegistry.add(OrientationFunctions.class);
+    funcRegistry.add(OrientationFPFunctions.class);
     funcRegistry.add(LineSegmentFunctions.class);
     funcRegistry.add(OverlayFunctions.class);
     
