@@ -11,7 +11,8 @@
  */
 package org.locationtech.jtstest.geomfunction;
 
-import java.lang.annotation.*;
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
 
 @Retention(RetentionPolicy.RUNTIME)
 public @interface Metadata
@@ -19,4 +20,5 @@ public @interface Metadata
   String name() default "";
   String title() default "";
   String description() default "";
+  boolean isRequired() default true;
 }
