@@ -17,10 +17,8 @@ import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.event.ActionEvent;
 import java.util.Comparator;
-
 import javax.swing.Box;
 import javax.swing.BoxLayout;
-import javax.swing.ImageIcon;
 import javax.swing.JButton;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
@@ -48,9 +46,9 @@ public class InspectorPanel extends TestBuilderPanel  {
 
   private Geometry geometry;
 
-  private Comparator sorterArea;
-
-  private Comparator sorterLen;
+  private Comparator<GeometricObjectNode> sorterArea;
+  private Comparator<GeometricObjectNode> sorterLen;
+  private Comparator<GeometricObjectNode> sorterNumPoints;
 
   public InspectorPanel() {
     this(true);
@@ -71,22 +69,22 @@ public class InspectorPanel extends TestBuilderPanel  {
     
     JButton btnZoom = SwingUtil.createButton(AppIcons.ZOOM, "Zoom to component", new java.awt.event.ActionListener() {
       public void actionPerformed(ActionEvent e) {
-        btnZoom_actionPerformed(e);
+        actionZoom(e);
       }
     });
-    JButton btnCopy = SwingUtil.createButton(AppIcons.COPY, "Copy (Ctl-click to copy formatted", new java.awt.event.ActionListener() {
+    JButton btnCopy = SwingUtil.createButton(AppIcons.COPY, "Copy (Ctl-click to Copy formatted", new java.awt.event.ActionListener() {
       public void actionPerformed(ActionEvent e) {
-        btnCopy_actionPerformed(e);
+        actionCopy(e);
       }
     });
-    JButton btnNext = SwingUtil.createButton(AppIcons.DOWN, "Zoom to Next", new java.awt.event.ActionListener() {
+    JButton btnNext = SwingUtil.createButton(AppIcons.DOWN, "Next (Ctl-click to Zoom)", new java.awt.event.ActionListener() {
       public void actionPerformed(ActionEvent e) {
-        btnZoomNext_actionPerformed(e, 1);
+         actionZoomNext(e, 1);
       }
     });
-    JButton btnPrev = SwingUtil.createButton(AppIcons.UP, "Zoom to Previous", new java.awt.event.ActionListener() {
+    JButton btnPrev = SwingUtil.createButton(AppIcons.UP, "Previous (Ctl-click to Zoom)", new java.awt.event.ActionListener() {
       public void actionPerformed(ActionEvent e) {
-        btnZoomNext_actionPerformed(e, -1);
+        actionZoomNext(e, -1);
       }
     });
     btnDelete = SwingUtil.createButton(AppIcons.DELETE, "Delete", new java.awt.event.ActionListener() {
@@ -115,24 +113,6 @@ public class InspectorPanel extends TestBuilderPanel  {
     btnPanel.add(btnDelete);
     this.add(btnPanel, BorderLayout.WEST);
     
-    if (showExpand) {
-      JPanel btn2Panel = new JPanel();
-      btn2Panel.setLayout(new BoxLayout(btn2Panel, BoxLayout.PAGE_AXIS));
-      btn2Panel.setPreferredSize(new java.awt.Dimension(30, 30));
-      btnExpand.setEnabled(true);
-      btnExpand.setMaximumSize(new Dimension(30, 30));
-      btnExpand.setText("...");
-      btnExpand.setToolTipText("Display in window");
-      btnExpand.addActionListener(new java.awt.event.ActionListener() {
-        public void actionPerformed(ActionEvent e)
-        {
-          btnExpand_actionPerformed();
-        }
-      });
-      btn2Panel.add(btnExpand);
-      this.add(btn2Panel, BorderLayout.EAST);
-    }
-    
     JButton btnSortNone = SwingUtil.createButton(AppIcons.CLEAR, "Unsorted", new java.awt.event.ActionListener() {
       public void actionPerformed(ActionEvent e) {
         sortNone();
@@ -148,34 +128,62 @@ public class InspectorPanel extends TestBuilderPanel  {
         sortByLen();
       }
     });
+    JButton btnSortByNumPts = SwingUtil.createButton(AppIcons.ICON_POINT, "Sort by Num Points (Asc/Desc)", new java.awt.event.ActionListener() {
+      public void actionPerformed(ActionEvent e) {
+        sortByNumPoints();
+      }
+    });
     
-    JPanel sortPanel = new JPanel();
-    sortPanel.setLayout(new BoxLayout(sortPanel, BoxLayout.LINE_AXIS));
-    sortPanel.add(Box.createRigidArea(new Dimension(160, 0)));
-    sortPanel.add(new JLabel("Sort"));
-    sortPanel.add(Box.createRigidArea(new Dimension(10, 0)));
-    sortPanel.add(btnSortNone);
-    //sortPanel.add(new JLabel(AppIcons.ICON_LINESTRING));
-    sortPanel.add(Box.createRigidArea(new Dimension(10, 0)));
-    sortPanel.add(btnSortByLen);
-    //sortPanel.add(new JLabel(AppIcons.ICON_POLYGON));
-    sortPanel.add(Box.createRigidArea(new Dimension(10, 0)));
-    sortPanel.add(btnSortByArea);
-    this.add(sortPanel, BorderLayout.NORTH);
-
+    JPanel btn2Panel = new JPanel();
+    btn2Panel.setLayout(new BoxLayout(btn2Panel, BoxLayout.PAGE_AXIS));
+    btn2Panel.setPreferredSize(new java.awt.Dimension(30, 30));
+    btnExpand.setMaximumSize(new Dimension(30, 30));
+    btnExpand.setText("...");
+    btnExpand.setToolTipText("Display in window");
+    btnExpand.addActionListener(new java.awt.event.ActionListener() {
+      public void actionPerformed(ActionEvent e)
+      {
+        btnExpand_actionPerformed();
+      }
+    });
+    if (showExpand) {
+      btnExpand.setEnabled(true);
+    }
+    btn2Panel.add(btnExpand);
+    
+    btn2Panel.add(Box.createRigidArea(new Dimension(0, 10)));
+    btn2Panel.add(new JLabel("Sort"));
+    btn2Panel.add(btnSortByNumPts);
+    btn2Panel.add(btnSortByLen);
+    btn2Panel.add(btnSortByArea);
+    btn2Panel.add(btnSortNone);
+    this.add(btn2Panel, BorderLayout.EAST);
   }
   private void btnExpand_actionPerformed() {
     JTSTestBuilder.controller().inspectGeometryDialogForCurrentCase();
   }
-  private void btnZoom_actionPerformed(ActionEvent e) {
-    JTSTestBuilderFrame.getGeometryEditPanel().zoom(geomTreePanel.getSelectedGeometry());
+  private void actionZoom(ActionEvent e) {
+    Geometry geom = geomTreePanel.getSelectedGeometry();
+    JTSTestBuilderFrame.getGeometryEditPanel().zoom(geom);
+    //-- would be nice to flash, but zoom is too slow
+    //JTSTestBuilder.controller().flash(geom);
   }
-  private void btnZoomNext_actionPerformed(ActionEvent e, int direction) {
+  private void actionZoomNext(ActionEvent e, int direction) {
+    boolean isZoom = SwingUtil.isCtlKeyPressed(e);
     geomTreePanel.moveToNextNode(direction);
-    JTSTestBuilderFrame.getGeometryEditPanel().zoom(geomTreePanel.getSelectedGeometry());
+    Geometry geom = geomTreePanel.getSelectedGeometry();
+    if (geom == null)
+      return;
+    if (isZoom) {
+      JTSTestBuilderFrame.getGeometryEditPanel().zoom(geom);
+      //-- would be nice to flash, but zoom is too slow
+    }
+    else {
+      JTSTestBuilder.controller().flash(geom);
+    }
   }
-  private void btnCopy_actionPerformed(ActionEvent e) {
-    boolean isFormatted = 0 != (e.getModifiers() & ActionEvent.CTRL_MASK);
+  private void actionCopy(ActionEvent e) {
+    boolean isFormatted = SwingUtil.isCtlKeyPressed(e);
     Geometry geom = geomTreePanel.getSelectedGeometry();
     if (geom == null) return;
     SwingUtil.copyToClipboard(geom, isFormatted);
@@ -196,7 +204,8 @@ public class InspectorPanel extends TestBuilderPanel  {
 
     btnDelete.setEnabled(isEditable);
     lblGeom.setText(tag);
-    lblGeom.setForeground(source == 0 ? Color.BLUE : Color.RED);
+    lblGeom.setToolTipText(tag);
+    lblGeom.setForeground(source == 0 ? AppColors.GEOM_A : AppColors.GEOM_B);
     
     sortNone();
   }
@@ -211,12 +220,14 @@ public class InspectorPanel extends TestBuilderPanel  {
   {
     sorterLen = null;
     sorterArea = null;
+    sorterNumPoints = null;
     geomTreePanel.populate(geometry, source);
   }
   
   public void sortByArea()
   {
     sorterLen = null;
+    sorterNumPoints = null;
     
     if (sorterArea == GeometryTreeModel.SORT_AREA_ASC) {
       sorterArea = GeometryTreeModel.SORT_AREA_DESC;
@@ -230,6 +241,8 @@ public class InspectorPanel extends TestBuilderPanel  {
   public void sortByLen()
   {
     sorterArea = null;
+    sorterNumPoints = null;
+    
     if (sorterLen == GeometryTreeModel.SORT_LEN_ASC) {
       sorterLen = GeometryTreeModel.SORT_LEN_DESC;
     }
@@ -239,6 +252,18 @@ public class InspectorPanel extends TestBuilderPanel  {
     geomTreePanel.populate(geometry, source, sorterLen);
   }
 
-
+  public void sortByNumPoints()
+  {
+    sorterArea = null;
+    sorterLen = null;
+    
+    if (sorterNumPoints == GeometryTreeModel.SORT_NUMPTS_ASC) {
+      sorterNumPoints = GeometryTreeModel.SORT_NUMPTS_DESC;
+    }
+    else {
+      sorterNumPoints = GeometryTreeModel.SORT_NUMPTS_ASC;
+    }
+    geomTreePanel.populate(geometry, source, sorterNumPoints);
+  }
   
 }
