@@ -13,22 +13,22 @@
 package org.locationtech.jtstest.testbuilder.controller;
 
 
-import java.util.List;
+import java.awt.Color;
 
 import javax.swing.JFileChooser;
 
 import org.locationtech.jts.geom.Coordinate;
 import org.locationtech.jts.geom.Geometry;
 import org.locationtech.jts.geom.util.LinearComponentExtracter;
-import org.locationtech.jtstest.testbuilder.TestBuilderDialogs;
-import org.locationtech.jtstest.testbuilder.geom.ComponentLocater;
-import org.locationtech.jtstest.testbuilder.geom.GeometryLocation;
 import org.locationtech.jtstest.clean.CleanDuplicatePoints;
+import org.locationtech.jtstest.testbuilder.AppConstants;
+import org.locationtech.jtstest.testbuilder.AppStrings;
 import org.locationtech.jtstest.testbuilder.GeometryEditPanel;
 import org.locationtech.jtstest.testbuilder.JTSTestBuilder;
 import org.locationtech.jtstest.testbuilder.JTSTestBuilderFrame;
 import org.locationtech.jtstest.testbuilder.JTSTestBuilderToolBar;
 import org.locationtech.jtstest.testbuilder.SpatialFunctionPanel;
+import org.locationtech.jtstest.testbuilder.TestBuilderDialogs;
 import org.locationtech.jtstest.testbuilder.model.GeometryEditModel;
 import org.locationtech.jtstest.testbuilder.model.LayerList;
 import org.locationtech.jtstest.testbuilder.model.TestBuilderModel;
@@ -167,6 +167,11 @@ public class JTSTestBuilderController
     toolbar().setFocusGeometry(index);    
   }
 
+  public void flash(Geometry geom)
+  {
+    JTSTestBuilderFrame.getGeometryEditPanel().flash(geom);
+  }
+  
   public void inspectGeometry()
   {
     JTSTestBuilderFrame.instance().inspectGeometry();
@@ -177,6 +182,10 @@ public class JTSTestBuilderController
     JTSTestBuilderFrame.instance().inspectResult();
   }
 
+  public void inspectGeometry(String tag, Geometry geometry) {
+    JTSTestBuilderFrame.instance().inspectGeometry(tag, geometry);
+  }
+
   public void inspectGeometryDialogForCurrentCase()
   {
     int geomIndex = JTSTestBuilder.model().getGeometryEditModel().getGeomIndex();
@@ -305,14 +314,13 @@ public class JTSTestBuilderController
     editPanel().zoomToGeometry(1);
   }
   
-  public void caseMoveToPrev(boolean isZoom) {
-    model().cases().prevCase();
-    frame().updateTestCaseView();
-    if (isZoom) zoomToInput();
-  }
-
-  public void caseMoveToNext(boolean isZoom) {
+  public void caseMoveTo(int dir, boolean isZoom) {
+    if (dir < 1) {
+      model().cases().prevCase();
+    }
+    else {
     model().cases().nextCase();
+    }
     frame().updateTestCaseView();
     if (isZoom) zoomToInput();
   }
@@ -372,4 +380,20 @@ public class JTSTestBuilderController
     model().getCurrentCase().setGeometry(0, cleanGeom);
     frame().geometryChanged();
   }
+  
+  //=============================================
+
+  public void indicatorShow(Geometry geom, Color lineClr)
+  {
+    if (! JTSTestBuilderFrame.isShowingIndicators()) return;
+    
+    if (JTSTestBuilderFrame.isSavingIndicators()) {
+      //-- refresh layer list panel only when indicator layer is created
+      boolean refreshLayerList = ! model().hasLayer(AppStrings.LYR_INDICATORS);
+      model().addIndicator(geom);
+      if (refreshLayerList) 
+        frame().refreshLayerList();
+    }
+    editPanel().draw(geom, lineClr, AppConstants.INDICATOR_FILL_CLR);
+  }
 }
