@@ -12,8 +12,12 @@
 
 package org.locationtech.jtstest.testbuilder.model;
 
-import org.locationtech.jts.geom.*;
+import org.locationtech.jts.geom.Geometry;
 
 public interface GeometryContainer {
   Geometry getGeometry();
+
+  default void clear() {
+    
+  }
 }
