@@ -57,8 +57,12 @@ public class GeometryCollection extends Geometry {
   }
 
   public Coordinate getCoordinate() {
-    if (isEmpty()) return null;
-    return geometries[0].getCoordinate();
+    for (int i = 0; i < geometries.length; i++) {
+      if (! geometries[i].isEmpty()) {
+        return geometries[i].getCoordinate();
+      }
+    }
+    return null;
   }
 
   /**
@@ -100,6 +104,14 @@ public class GeometryCollection extends Geometry {
     return dimension;
   }
 
+  public boolean hasDimension(int dim) {
+    for (int i = 0; i < geometries.length; i++) {
+      if (geometries[i].hasDimension(dim))
+        return true;
+    }
+    return false;
+  }
+  
   public int getBoundaryDimension() {
     int dimension = Dimension.FALSE;
     for (int i = 0; i < geometries.length; i++) {
