@@ -1,4 +1,3 @@
-
 /*
  * Copyright (c) 2016 Vivid Solutions.
  *
@@ -27,14 +26,16 @@ import org.locationtech.jts.util.Assert;
 
 
 /**
- *  A query-only R-tree created using the Sort-Tile-Recursive (STR) algorithm.
- *  For two-dimensional spatial data.
+ * A query-only R-tree created using the Sort-Tile-Recursive (STR) algorithm.
+ * For two-dimensional spatial data.
  * <P>
- *  The STR packed R-tree is simple to implement and maximizes space
- *  utilization; that is, as many leaves as possible are filled to capacity.
- *  Overlap between nodes is far less than in a basic R-tree. However, once the
- *  tree has been built (explicitly or on the first call to #query), items may
- *  not be added or removed.
+ * The STR packed R-tree is simple to implement and maximizes space
+ * utilization; that is, as many leaves as possible are filled to capacity.
+ * Overlap between nodes is far less than in a basic R-tree. 
+ * However, the index is semi-static; once the tree has been built 
+ * (which happens automatically upon the first query), items may
+ * not be added.
+ * Items may be removed from the tree using {@link #remove(Envelope, Object)}.
  * <P>
  * Described in: P. Rigaux, Michel Scholl and Agnes Voisard.
  * <i>Spatial Databases With Application To GIS</i>.
@@ -53,9 +54,9 @@ public class STRtree extends AbstractSTRtree
 implements SpatialIndex, Serializable 
 {
 
-  private static final class STRtreeNode extends AbstractNode
+  static final class STRtreeNode extends AbstractNode
   {
-    private STRtreeNode(int level)
+    STRtreeNode(int level)
     {
       super(level);
     }
@@ -184,6 +185,28 @@ implements SpatialIndex, Serializable
     super(nodeCapacity);
   }
 
+  /**
+   * Constructs an STRtree with the given maximum number of child nodes that
+   * a node may have, and the root that links to all other nodes
+   * <p>
+   * The minimum recommended capacity setting is 4.
+   *
+   */
+  public STRtree(int nodeCapacity, STRtreeNode root) {
+    super(nodeCapacity, root);
+  }
+
+  /**
+   * Constructs an STRtree with the given maximum number of child nodes that
+   * a node may have, and all leaf nodes in the tree
+   * <p>
+   * The minimum recommended capacity setting is 4.
+   *
+   */
+  public STRtree(int nodeCapacity, ArrayList itemBoundables) {
+    super(nodeCapacity, itemBoundables);
+  }
+
   protected AbstractNode createNode(int level) {
     return new STRtreeNode(level);
   }
@@ -206,7 +229,7 @@ implements SpatialIndex, Serializable
   public List query(Envelope searchEnv) {
     //Yes this method does something. It specifies that the bounds is an
     //Envelope. super.query takes an Object, not an Envelope. [Jon Aquino 10/24/2003]
-    return super.query(searchEnv);
+    return super.query((Object)searchEnv);
   }
 
   /**
@@ -240,9 +263,9 @@ implements SpatialIndex, Serializable
   }
 
   /**
-   * Returns the number of items in the tree.
+   * Returns the number of levels in the tree.
    *
-   * @return the number of items in the tree
+   * @return the number of levels in the tree
    */
   public int depth()
   {
@@ -298,6 +321,8 @@ implements SpatialIndex, Serializable
    */
   public Object nearestNeighbour(Envelope env, Object item, ItemDistance itemDist)
   {
+    if (isEmpty()) return null;
+
     Boundable bnd = new ItemBoundable(env, item);
     BoundablePair bp = new BoundablePair(this.getRoot(), bnd, itemDist);
     return nearestNeighbour(bp)[0];
@@ -474,7 +499,7 @@ implements SpatialIndex, Serializable
   }
  
   /**
-   * Finds k items in this tree which are the top k nearest neighbors to the given {@code item}, 
+   * Finds up to k items in this tree which are the nearest neighbors to the given {@code item}, 
    * using {@code itemDist} as the distance metric.
    * A Branch-and-Bound tree traversal algorithm is used
    * to provide an efficient search.
@@ -487,15 +512,20 @@ implements SpatialIndex, Serializable
    * contained in the tree, but it does 
    * have to be compatible with the {@code itemDist} 
    * distance metric. 
+   * <p>
+   * If the tree size is smaller than k fewer items will be returned.
+   * If the tree is empty an array of size 0 is returned.
    * 
    * @param env the envelope of the query item
-   * @param item the item to find the nearest neighbour of
+   * @param item the item to find the nearest neighbours of
    * @param itemDist a distance metric applicable to the items in this tree and the query item
-   * @param k the K nearest items in kNearestNeighbour
-   * @return the K nearest items in this tree
+   * @param k the maximum number of nearest items to search for
+   * @return an array of the nearest items found (with length between 0 and K)
    */
   public Object[] nearestNeighbour(Envelope env, Object item, ItemDistance itemDist,int k)
   {
+    if (isEmpty()) return new Object[0];
+
     Boundable bnd = new ItemBoundable(env, item);
     BoundablePair bp = new BoundablePair(this.getRoot(), bnd, itemDist);
     return nearestNeighbourK(bp,k);
