@@ -18,12 +18,15 @@ import java.io.StreamTokenizer;
 import java.io.StringReader;
 import java.util.ArrayList;
 import java.util.EnumSet;
+import java.util.List;
 import java.util.Locale;
 
 import org.locationtech.jts.geom.Coordinate;
 import org.locationtech.jts.geom.CoordinateSequence;
 import org.locationtech.jts.geom.CoordinateSequenceFactory;
-
+import org.locationtech.jts.geom.CoordinateXY;
+import org.locationtech.jts.geom.CoordinateXYM;
+import org.locationtech.jts.geom.CoordinateXYZM;
 import org.locationtech.jts.geom.Geometry;
 import org.locationtech.jts.geom.GeometryCollection;
 import org.locationtech.jts.geom.GeometryFactory;
@@ -55,7 +58,21 @@ import org.locationtech.jts.util.AssertionFailedException;
  *
  *  The <code>WKTReader</code> converts all input numbers to the precise
  *  internal representation.
- *
+ *  <p>
+ * As of version 1.15, JTS can read (but not write) WKT syntax
+ * which specifies coordinate dimension Z, M or ZM as modifiers (e.g. POINT Z)
+ * or in the name of the geometry type (e.g. LINESTRINGZM).
+ * If the coordinate dimension is specified it will be set in the created geometry.
+ * If the coordinate dimension is not specified, the default behaviour is to 
+ * create XYZ geometry (this is backwards compatible with older JTS versions).  
+ * This can be altered to create XY geometry by
+ * calling {@link #setIsOldJtsCoordinateSyntaxAllowed(boolean)}.
+ * <p>
+ * A reader can be set to ensure the input is structurally valid
+ * by calling {@link #setFixStructure(boolean)}.
+ * This ensures that geometry can be constructed without errors due to missing coordinates.
+ * The created geometry may still be topologically invalid.
+ * 
  * <h3>Notes:</h3>
  * <ul>
  * <li>Keywords are case-insensitive.
@@ -64,17 +81,11 @@ import org.locationtech.jts.util.AssertionFailedException;
  * numbers to floating point.  This means it supports the Java
  * syntax for floating point literals (including scientific notation).
  * </ul>
- *
  * <h3>Syntax</h3>
  * The following syntax specification describes the version of Well-Known Text
  * supported by JTS.
  * (The specification uses a syntax language similar to that used in
  * the C and Java language specifications.)
- * <p>
- * As of version 1.15, JTS can read (but not write) WKT Strings including Z, M or ZM
- * in the name of the geometry type (ex. POINT Z, LINESTRINGZM).
- * Note that it only makes the reader more flexible, but JTS could already read
- * 3D coordinates from WKT String and still can't read 4D coordinates.
  *
  * <blockquote><pre>
  * <i>WKTGeometry:</i> one of<i>
@@ -118,7 +129,7 @@ import org.locationtech.jts.util.AssertionFailedException;
  *         | <b>EMPTY</b>
  *
  * <i>Coordinate:
- *         Number Number Number<sub>opt</sub></i>
+ *         Number Number Number<sub>opt</sub> Number<sub>opt</sub></i>
  *
  * <i>Number:</i> A Java-style floating-point number (including <tt>NaN</tt>, with arbitrary case)
  *
@@ -133,7 +144,6 @@ import org.locationtech.jts.util.AssertionFailedException;
  */
 public class WKTReader
 {
-  private static final String EMPTY = "EMPTY";
   private static final String COMMA = ",";
   private static final String L_PAREN = "(";
   private static final String R_PAREN = ")";
@@ -157,6 +167,9 @@ public class WKTReader
    */
   private static final boolean ALLOW_OLD_JTS_MULTIPOINT_SYNTAX = true;
   private boolean isAllowOldJtsMultipointSyntax = ALLOW_OLD_JTS_MULTIPOINT_SYNTAX;
+  
+  
+  private boolean isFixStructure = false;
 
   /**
    * Creates a reader that creates objects using the default {@link GeometryFactory}.
@@ -196,6 +209,19 @@ public class WKTReader
     isAllowOldJtsMultipointSyntax = value;
   }
 
+  /**
+   * Sets a flag indicating that the structure of input geometry should be fixed
+   * so that the geometry can be constructed without error.
+   * This involves adding coordinates if the input coordinate sequence is shorter than required.
+   * 
+   * @param isFixStructure true if the input structure should be fixed
+   * 
+   * @see LinearRing#MINIMUM_VALID_SIZE
+   */
+  public void setFixStructure(boolean isFixStructure) {
+    this.isFixStructure = isFixStructure;
+  }
+  
   /**
    * Reads a Well-Known Text representation of a {@link Geometry}
    * from a {@link String}.
@@ -262,49 +288,60 @@ public class WKTReader
   /**
    * Reads a <code>Coordinate</Code> from a stream using the given {@link StreamTokenizer}.
    * <p>
-   *   All ordinate values are read, but -depending on the {@link CoordinateSequenceFactory} of the
-   *   underlying {@link GeometryFactory}- not necessarily all can be handled. Those are silently dropped.
+   * All ordinate values are read, but -depending on the {@link CoordinateSequenceFactory} of the
+   * underlying {@link GeometryFactory}- not necessarily all can be handled. Those are silently dropped.
    * </p>
    * @param tokenizer the tokenizer to use
    * @param ordinateFlags a bit-mask defining the ordinates to read.
    * @param tryParen a value indicating if a starting {@link #L_PAREN} should be probed.
-   * @return a {@link CoordinateSequence} of length 1 containing the read ordinate values
+   * @return a {@link Coordinate} of appropriate dimension containing the read ordinate values
    *
    *@throws  IOException     if an I/O error occurs
    *@throws  ParseException  if an unexpected token was encountered
    */
-  private CoordinateSequence getCoordinate(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags, boolean tryParen)
-          throws IOException, ParseException
+  private Coordinate getCoordinate(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags, boolean tryParen)
+      throws IOException, ParseException
   {
-
     boolean opened = false;
     if (tryParen && isOpenerNext(tokenizer) ) {
       tokenizer.nextToken();
       opened = true;
     }
-
+    
     // create a sequence for one coordinate
     int offsetM = ordinateFlags.contains(Ordinate.Z) ? 1 : 0;
-    CoordinateSequence sequence = csFactory.create(1, toDimension(ordinateFlags), ordinateFlags.contains(Ordinate.M) ? 1 : 0);
-    sequence.setOrdinate(0, CoordinateSequence.X, precisionModel.makePrecise(getNextNumber(tokenizer)));
-    sequence.setOrdinate(0, CoordinateSequence.Y, precisionModel.makePrecise(getNextNumber(tokenizer)));
-
+    Coordinate coord = createCoordinate(ordinateFlags);
+    coord.setOrdinate(CoordinateSequence.X, precisionModel.makePrecise(getNextNumber(tokenizer)));
+    coord.setOrdinate(CoordinateSequence.Y, precisionModel.makePrecise(getNextNumber(tokenizer)));
+    
     // additionally read other vertices
     if (ordinateFlags.contains(Ordinate.Z))
-      sequence.setOrdinate(0, CoordinateSequence.Z, getNextNumber(tokenizer));
+      coord.setOrdinate(CoordinateSequence.Z, getNextNumber(tokenizer));
     if (ordinateFlags.contains(Ordinate.M))
-      sequence.setOrdinate(0, CoordinateSequence.Z + offsetM, getNextNumber(tokenizer));
-
+      coord.setOrdinate(CoordinateSequence.Z + offsetM, getNextNumber(tokenizer));
+    
     if (ordinateFlags.size() == 2 && this.isAllowOldJtsCoordinateSyntax && isNumberNext(tokenizer)) {
-      sequence.setOrdinate(0, CoordinateSequence.Z, getNextNumber(tokenizer));
+      coord.setOrdinate(CoordinateSequence.Z, getNextNumber(tokenizer));
     }
-
+    
     // read close token if it was opened here
     if (opened) {
       getNextCloser(tokenizer);
     }
-
-    return sequence;
+    
+    return coord;
+  }
+  
+  private Coordinate createCoordinate(EnumSet<Ordinate> ordinateFlags) {
+    boolean hasZ = ordinateFlags.contains(Ordinate.Z);
+    boolean hasM = ordinateFlags.contains(Ordinate.M);
+    if (hasZ && hasM) 
+      return new CoordinateXYZM();
+    if (hasM)
+      return new CoordinateXYM();
+    if (hasZ || this.isAllowOldJtsCoordinateSyntax) 
+      return new Coordinate();
+    return new CoordinateXY();
   }
 
   /**
@@ -323,39 +360,74 @@ public class WKTReader
    *@throws  IOException     if an I/O error occurs
    *@throws  ParseException  if an unexpected token was encountered
    */
-  private CoordinateSequence getCoordinateSequence(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags)
+  private CoordinateSequence getCoordinateSequence(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags, int minSize, boolean isRing)
           throws IOException, ParseException {
-    return getCoordinateSequence(tokenizer, ordinateFlags, false);
+    if (getNextEmptyOrOpener(tokenizer).equals(WKTConstants.EMPTY))
+      return createCoordinateSequenceEmpty(ordinateFlags);
+    
+    List<Coordinate> coordinates = new ArrayList<Coordinate>();
+    do {
+      coordinates.add(getCoordinate(tokenizer, ordinateFlags, false));
+    } while (getNextCloserOrComma(tokenizer).equals(COMMA));
+
+    if (isFixStructure) {
+      fixStructure(coordinates, minSize, isRing);
+    }
+    Coordinate[] coordArray = coordinates.toArray(new Coordinate[0]);
+    return csFactory.create(coordArray);
+  }
+
+  private static void fixStructure(List<Coordinate> coords, int minSize, boolean isRing) {
+    if (coords.size() == 0)
+      return;
+    if (isRing && ! isClosed(coords)) {
+        coords.add(coords.get(0).copy());
+      }
+    while (coords.size() < minSize) {
+      coords.add(coords.get(coords.size() - 1).copy());
+    }
+  }
+
+  private static boolean isClosed(List<Coordinate> coords) {
+    if (coords.size() == 0) return true;
+    if (coords.size() == 1 
+        || ! coords.get(0).equals2D(coords.get(coords.size() - 1))) {
+      return false;
+    } 
+    return true;
+  }
+
+  private CoordinateSequence createCoordinateSequenceEmpty(EnumSet<Ordinate> ordinateFlags)
+      throws IOException, ParseException {
+    return csFactory.create(0, toDimension(ordinateFlags), ordinateFlags.contains(Ordinate.M) ? 1 : 0);
   }
 
   /**
-   * Reads a <code>CoordinateSequence</Code> from a stream using the given {@link StreamTokenizer}.
+   * Reads a <code>CoordinateSequence</Code> from a stream using the given {@link StreamTokenizer}
+   * for an old-style JTS MultiPoint (Point coordinates not enclosed in parentheses).
    * <p>
-   *   All ordinate values are read, but -depending on the {@link CoordinateSequenceFactory} of the
-   *   underlying {@link GeometryFactory}- not necessarily all can be handled. Those are silently dropped.
+   * All ordinate values are read, but -depending on the {@link CoordinateSequenceFactory} of the
+   * underlying {@link GeometryFactory}- not necessarily all can be handled. Those are silently dropped.
    * </p>
    * @param tokenizer the tokenizer to use
    * @param ordinateFlags a bit-mask defining the ordinates to read.
    * @param tryParen a value indicating if a starting {@link #L_PAREN} should be probed for each coordinate.
+   * @param isReadEmptyOrOpener indicates if an opening paren or EMPTY should be scanned for
    * @return a {@link CoordinateSequence} of length 1 containing the read ordinate values
    *
-   *@throws  IOException     if an I/O error occurs
-   *@throws  ParseException  if an unexpected token was encountered
-S   */
-  private CoordinateSequence getCoordinateSequence(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags,
-                                                   boolean tryParen)
+   * @throws  IOException     if an I/O error occurs
+   * @throws  ParseException  if an unexpected token was encountered
+S  */
+  private CoordinateSequence getCoordinateSequenceOldMultiPoint(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags)
           throws IOException, ParseException {
 
-    if (getNextEmptyOrOpener(tokenizer).equals(EMPTY))
-      return this.csFactory.create(0, toDimension(ordinateFlags), ordinateFlags.contains(Ordinate.M) ? 1 : 0);
-
-    ArrayList coordinates = new ArrayList();
+    List<Coordinate> coordinates = new ArrayList<Coordinate>();
     do {
-      coordinates.add(getCoordinate(tokenizer, ordinateFlags, tryParen));
+      coordinates.add(getCoordinate(tokenizer, ordinateFlags, true));
     } while (getNextCloserOrComma(tokenizer).equals(COMMA));
 
-    return mergeSequences(coordinates, ordinateFlags);
-  }
+    Coordinate[] coordArray = coordinates.toArray(new Coordinate[0]);
+    return csFactory.create(coordArray);  }
 
   /**
    * Computes the required dimension based on the given ordinate values.
@@ -377,137 +449,6 @@ S   */
     return dimension;
   }
 
-  /**
-   * Merges an array of one-coordinate-{@link CoordinateSequence}s into one {@link CoordinateSequence}.
-   *
-   * @param sequences an array of coordinate sequences. Each sequence contains <b>exactly one</b> coordinate.
-   * @param ordinateFlags a bit-mask of required ordinates.
-   * @return a coordinate sequence containing all coordinate
-   */
-  private CoordinateSequence mergeSequences(ArrayList sequences, EnumSet<Ordinate> ordinateFlags) {
-
-    // if the sequences array is empty or null create an empty sequence
-    if (sequences == null || sequences.size() == 0)
-      return csFactory.create(0, toDimension(ordinateFlags));
-
-    if (sequences.size() == 1)
-      return (CoordinateSequence) sequences.get(0);
-
-    EnumSet<Ordinate> mergeOrdinates;
-    if (this.isAllowOldJtsCoordinateSyntax && ordinateFlags.size() == 2) {
-      mergeOrdinates = ordinateFlags.clone();
-      for (int i = 0; i < sequences.size(); i++) {
-        if (((CoordinateSequence)sequences.get(i)).hasZ()) {
-          mergeOrdinates.add(Ordinate.Z);
-          break;
-        }
-      }
-    }
-    else
-      mergeOrdinates = ordinateFlags;
-
-    // create and fill the result sequence
-    CoordinateSequence sequence = this.csFactory.create(sequences.size(), toDimension(mergeOrdinates),
-            mergeOrdinates.contains(Ordinate.M) ? 1 : 0);
-
-    int offsetM = CoordinateSequence.Z + (mergeOrdinates.contains(Ordinate.Z) ? 1 : 0);
-    for (int i = 0; i < sequences.size(); i++) {
-      CoordinateSequence item = (CoordinateSequence)sequences.get(i);
-      sequence.setOrdinate(i, CoordinateSequence.X, item.getOrdinate(0, CoordinateSequence.X));
-      sequence.setOrdinate(i, CoordinateSequence.Y, item.getOrdinate(0, CoordinateSequence.Y));
-      if (mergeOrdinates.contains(Ordinate.Z))
-        sequence.setOrdinate(i, CoordinateSequence.Z, item.getOrdinate(0, CoordinateSequence.Z));
-      if (mergeOrdinates.contains(Ordinate.M))
-        sequence.setOrdinate(i, offsetM, item.getOrdinate(0, offsetM));
-    }
-
-    // return it
-    return sequence;
-  }
-
-  /**
-   * Returns the next array of <code>Coordinate</code>s in the stream.
-   *
-   *@param  tokenizer        tokenizer over a stream of text in Well-known Text
-   *      format. The next element returned by the stream should be L_PAREN (the
-   *      beginning of "(x1 y1, x2 y2, ..., xn yn)") or EMPTY.
-   *@return                  the next array of <code>Coordinate</code>s in the
-   *      stream, or an empty array if EMPTY is the next element returned by
-   *      the stream.
-   *@throws  IOException     if an I/O error occurs
-   *@throws  ParseException  if an unexpected token was encountered
-   *
-   *@deprecated in favor of functions returning {@link CoordinateSequence}s
-   */
-  private Coordinate[] getCoordinates(StreamTokenizer tokenizer) throws IOException, ParseException {
-    String nextToken = getNextEmptyOrOpener(tokenizer);
-    if (nextToken.equals(EMPTY)) {
-      return new Coordinate[] {};
-    }
-    ArrayList coordinates = new ArrayList();
-    coordinates.add(getPreciseCoordinate(tokenizer));
-    nextToken = getNextCloserOrComma(tokenizer);
-    while (nextToken.equals(COMMA)) {
-      coordinates.add(getPreciseCoordinate(tokenizer));
-      nextToken = getNextCloserOrComma(tokenizer);
-    }
-    Coordinate[] array = new Coordinate[coordinates.size()];
-    return (Coordinate[]) coordinates.toArray(array);
-  }
-
-  /**
-   * Returns the next array of <code>Coordinate</code>s in the stream.
-   *
-   *@param  tokenizer        tokenizer over a stream of text in Well-known Text
-   *      format. The next element returned by the stream should be a number.
-   *@return                  the next array of <code>Coordinate</code>s in the
-   *      stream.
-   *@throws  IOException     if an I/O error occurs
-   *@throws  ParseException  if an unexpected token was encountered
-   *
-   *@deprecated in favor of functions returning {@link CoordinateSequence}s
-   */
-  private Coordinate[] getCoordinatesNoLeftParen(StreamTokenizer tokenizer) throws IOException, ParseException {
-    String nextToken = null;
-    ArrayList coordinates = new ArrayList();
-    coordinates.add(getPreciseCoordinate(tokenizer));
-    nextToken = getNextCloserOrComma(tokenizer);
-    while (nextToken.equals(COMMA)) {
-      coordinates.add(getPreciseCoordinate(tokenizer));
-      nextToken = getNextCloserOrComma(tokenizer);
-    }
-    Coordinate[] array = new Coordinate[coordinates.size()];
-    return (Coordinate[]) coordinates.toArray(array);
-  }
-
-  /**
-   * Returns the next precise <code>Coordinate</code> in the stream.
-   *
-   *@param  tokenizer        tokenizer over a stream of text in Well-known Text
-   *      format. The next element returned by the stream should be a number.
-   *@return                  the next array of <code>Coordinate</code>s in the
-   *      stream.
-   *@throws  IOException     if an I/O error occurs
-   *@throws  ParseException  if an unexpected token was encountered
-   *
-   *@deprecated in favor of functions returning {@link CoordinateSequence}s
-   */
-  private Coordinate getPreciseCoordinate(StreamTokenizer tokenizer)
-      throws IOException, ParseException
-  {
-    Coordinate coord = new Coordinate();
-    coord.x = getNextNumber(tokenizer);
-    coord.y = getNextNumber(tokenizer);
-    if (isNumberNext(tokenizer)) {
-        coord.setZ(getNextNumber(tokenizer));
-    }
-    if (isNumberNext(tokenizer)) {
-      getNextNumber(tokenizer); // ignore M value
-    }
-    precisionModel.makePrecise(coord);
-    return coord;
-  }
-
   /**
    * Tests if the next token in the stream is a number
    *
@@ -578,23 +519,23 @@ S   */
    */
   private static String getNextEmptyOrOpener(StreamTokenizer tokenizer) throws IOException, ParseException {
     String nextWord = getNextWord(tokenizer);
-    if (nextWord.equalsIgnoreCase("Z")) {
+    if (nextWord.equalsIgnoreCase(WKTConstants.Z)) {
       //z = true;
       nextWord = getNextWord(tokenizer);
     }
-    else if (nextWord.equalsIgnoreCase("M")) {
+    else if (nextWord.equalsIgnoreCase(WKTConstants.M)) {
       //m = true;
       nextWord = getNextWord(tokenizer);
     }
-    else if (nextWord.equalsIgnoreCase("ZM")) {
+    else if (nextWord.equalsIgnoreCase(WKTConstants.ZM)) {
       //z = true;
       //m = true;
       nextWord = getNextWord(tokenizer);
     }
-    if (nextWord.equals(EMPTY) || nextWord.equals(L_PAREN)) {
+    if (nextWord.equals(WKTConstants.EMPTY) || nextWord.equals(L_PAREN)) {
       return nextWord;
     }
-    throw parseErrorExpected(tokenizer, EMPTY + " or " + L_PAREN);
+    throw parseErrorExpected(tokenizer, WKTConstants.EMPTY + " or " + L_PAREN);
   }
 
   /**
@@ -612,15 +553,15 @@ S   */
     EnumSet<Ordinate> result = EnumSet.of(Ordinate.X, Ordinate.Y);
 
     String nextWord = lookAheadWord(tokenizer).toUpperCase(Locale.ROOT);
-    if (nextWord.equalsIgnoreCase("Z")) {
+    if (nextWord.equalsIgnoreCase(WKTConstants.Z)) {
       tokenizer.nextToken();
       result.add(Ordinate.Z);
     }
-    else if (nextWord.equalsIgnoreCase("M")) {
+    else if (nextWord.equalsIgnoreCase(WKTConstants.M)) {
       tokenizer.nextToken();
       result.add(Ordinate.M);
     }
-    else if (nextWord.equalsIgnoreCase("ZM")) {
+    else if (nextWord.equalsIgnoreCase(WKTConstants.ZM)) {
       tokenizer.nextToken();
       result.add(Ordinate.Z);
       result.add(Ordinate.M);
@@ -690,8 +631,8 @@ S   */
     case StreamTokenizer.TT_WORD:
 
       String word = tokenizer.sval;
-      if (word.equalsIgnoreCase(EMPTY))
-          return EMPTY;
+      if (word.equalsIgnoreCase(WKTConstants.EMPTY))
+          return WKTConstants.EMPTY;
       return word;
 
     case '(': return L_PAREN;
@@ -765,22 +706,15 @@ S   */
     String type;
 
     EnumSet<Ordinate> ordinateFlags = EnumSet.of(Ordinate.X, Ordinate.Y);
-    try {
-      type = getNextWord(tokenizer).toUpperCase(Locale.ROOT);
-      if (type.endsWith("ZM")) {
-        ordinateFlags.add(Ordinate.Z);
-        ordinateFlags.add(Ordinate.M);
-      } else if (type.endsWith("Z")) {
-        ordinateFlags.add(Ordinate.Z);
-      } else if (type.endsWith("M")) {
-        ordinateFlags.add(Ordinate.M);
-      }
-    } catch (IOException e) {
-      return null;
-    } catch (ParseException e) {
-      return null;
+    type = getNextWord(tokenizer).toUpperCase(Locale.ROOT);
+    if (type.endsWith(WKTConstants.ZM)) {
+      ordinateFlags.add(Ordinate.Z);
+      ordinateFlags.add(Ordinate.M);
+    } else if (type.endsWith(WKTConstants.Z)) {
+      ordinateFlags.add(Ordinate.Z);
+    } else if (type.endsWith(WKTConstants.M)) {
+      ordinateFlags.add(Ordinate.M);
     }
-
     return readGeometryTaggedText(tokenizer, type, ordinateFlags);
   }
 
@@ -804,33 +738,50 @@ S   */
               geometryFactory.getSRID(), csFactoryXYZM);
     }
 
-    if (type.startsWith("POINT")) {
+    if (isTypeName(tokenizer, type, WKTConstants.POINT)) {
       return readPointText(tokenizer, ordinateFlags);
     }
-    else if (type.startsWith("LINESTRING")) {
+    else if (isTypeName(tokenizer, type, WKTConstants.LINESTRING)) {
       return readLineStringText(tokenizer, ordinateFlags);
     }
-    else if (type.startsWith("LINEARRING")) {
+    else if (isTypeName(tokenizer, type, WKTConstants.LINEARRING)) {
       return readLinearRingText(tokenizer, ordinateFlags);
     }
-    else if (type.startsWith("POLYGON")) {
+    else if (isTypeName(tokenizer, type, WKTConstants.POLYGON)) {
       return readPolygonText(tokenizer, ordinateFlags);
     }
-    else if (type.startsWith("MULTIPOINT")) {
+    else if (isTypeName(tokenizer, type, WKTConstants.MULTIPOINT)) {
       return readMultiPointText(tokenizer, ordinateFlags);
     }
-    else if (type.startsWith("MULTILINESTRING")) {
+    else if (isTypeName(tokenizer, type, WKTConstants.MULTILINESTRING)) {
       return readMultiLineStringText(tokenizer, ordinateFlags);
     }
-    else if (type.startsWith("MULTIPOLYGON")) {
+    else if (isTypeName(tokenizer, type, WKTConstants.MULTIPOLYGON)) {
       return readMultiPolygonText(tokenizer, ordinateFlags);
     }
-    else if (type.startsWith("GEOMETRYCOLLECTION")) {
+    else if (isTypeName(tokenizer, type, WKTConstants.GEOMETRYCOLLECTION)) {
       return readGeometryCollectionText(tokenizer, ordinateFlags);
     }
     throw parseErrorWithLine(tokenizer, "Unknown geometry type: " + type);
   }
 
+  private boolean isTypeName(StreamTokenizer tokenizer, String type, String typeName) throws ParseException {
+    if (! type.startsWith(typeName))
+      return false;
+    
+    String modifiers = type.substring(typeName.length());
+    boolean isValidMod = modifiers.length() <= 2 &&
+        (modifiers.length() == 0
+        ||modifiers.equals(WKTConstants.Z)
+        || modifiers.equals(WKTConstants.M)
+        || modifiers.equals(WKTConstants.ZM));
+    if (! isValidMod) {
+      throw parseErrorWithLine(tokenizer, "Invalid dimension modifiers: " + type);
+    }
+    
+    return true;
+  }
+
   /**
    *  Creates a <code>Point</code> using the next token in the stream.
    *
@@ -842,7 +793,7 @@ S   */
    *@throws  ParseException  if an unexpected token was encountered
    */
   private Point readPointText(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags) throws IOException, ParseException {
-    Point point = geometryFactory.createPoint(getCoordinateSequence(tokenizer, ordinateFlags));
+    Point point = geometryFactory.createPoint(getCoordinateSequence(tokenizer, ordinateFlags, 1, false));
     return point;
   }
 
@@ -857,7 +808,7 @@ S   */
    *@throws  ParseException  if an unexpected token was encountered
    */
   private LineString readLineStringText(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags) throws IOException, ParseException {
-    return geometryFactory.createLineString(getCoordinateSequence(tokenizer, ordinateFlags));
+    return geometryFactory.createLineString(getCoordinateSequence(tokenizer, ordinateFlags, LineString.MINIMUM_VALID_SIZE, false));
   }
 
   /**
@@ -875,7 +826,7 @@ S   */
   private LinearRing readLinearRingText(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags)
     throws IOException, ParseException
   {
-    return geometryFactory.createLinearRing(getCoordinateSequence(tokenizer, ordinateFlags));
+    return geometryFactory.createLinearRing(getCoordinateSequence(tokenizer, ordinateFlags, LinearRing.MINIMUM_VALID_SIZE, true));
   }
 
   /**
@@ -890,8 +841,32 @@ S   */
    */
   private MultiPoint readMultiPointText(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags) throws IOException, ParseException
   {
-    return geometryFactory.createMultiPoint(
-            getCoordinateSequence(tokenizer, ordinateFlags, this.isAllowOldJtsMultipointSyntax));
+    String nextToken = getNextEmptyOrOpener(tokenizer);
+    if (nextToken.equals(WKTConstants.EMPTY)) {
+      return geometryFactory.createMultiPoint(new Point[0]);
+    }
+    
+    // check for old-style JTS syntax (no parentheses surrounding Point coordinates) and parse it if present
+    // MD 2009-02-21 - this is only provided for backwards compatibility for a few versions
+    if (isAllowOldJtsMultipointSyntax) {
+      String nextWord = lookAheadWord(tokenizer);
+      if (nextWord != L_PAREN && nextWord != WKTConstants.EMPTY) {
+        return geometryFactory.createMultiPoint(
+            getCoordinateSequenceOldMultiPoint(tokenizer, ordinateFlags));
+      }
+    }
+    
+    List<Point> points = new ArrayList<Point>();
+    Point point = readPointText(tokenizer, ordinateFlags);
+    points.add(point);
+    nextToken = getNextCloserOrComma(tokenizer);
+    while (nextToken.equals(COMMA)) {
+      point = readPointText(tokenizer, ordinateFlags);
+      points.add(point);
+      nextToken = getNextCloserOrComma(tokenizer);
+    }
+    Point[] array = new Point[points.size()];
+    return geometryFactory.createMultiPoint((Point[]) points.toArray(array));
   }
 
 
@@ -909,10 +884,10 @@ S   */
    */
   private Polygon readPolygonText(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags) throws IOException, ParseException {
     String nextToken = getNextEmptyOrOpener(tokenizer);
-    if (nextToken.equals(EMPTY)) {
-        return geometryFactory.createPolygon();
+    if (nextToken.equals(WKTConstants.EMPTY)) {
+        return geometryFactory.createPolygon(createCoordinateSequenceEmpty(ordinateFlags));
     }
-    ArrayList holes = new ArrayList();
+    List<LinearRing> holes = new ArrayList<LinearRing>();
     LinearRing shell = readLinearRingText(tokenizer, ordinateFlags);
     nextToken = getNextCloserOrComma(tokenizer);
     while (nextToken.equals(COMMA)) {
@@ -937,11 +912,11 @@ S   */
   private MultiLineString readMultiLineStringText(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags)
           throws IOException, ParseException {
     String nextToken = getNextEmptyOrOpener(tokenizer);
-    if (nextToken.equals(EMPTY)) {
+    if (nextToken.equals(WKTConstants.EMPTY)) {
       return geometryFactory.createMultiLineString();
     }
 
-    ArrayList lineStrings = new ArrayList();
+    List<LineString> lineStrings = new ArrayList<LineString>();
     do {
       LineString lineString = readLineStringText(tokenizer, ordinateFlags);
       lineStrings.add(lineString);
@@ -965,10 +940,10 @@ S   */
    */
   private MultiPolygon readMultiPolygonText(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags) throws IOException, ParseException {
     String nextToken = getNextEmptyOrOpener(tokenizer);
-    if (nextToken.equals(EMPTY)) {
+    if (nextToken.equals(WKTConstants.EMPTY)) {
       return geometryFactory.createMultiPolygon();
     }
-    ArrayList polygons = new ArrayList();
+    List<Polygon> polygons = new ArrayList<Polygon>();
     do {
       Polygon polygon = readPolygonText(tokenizer, ordinateFlags);
       polygons.add(polygon);
@@ -993,10 +968,10 @@ S   */
    */
   private GeometryCollection readGeometryCollectionText(StreamTokenizer tokenizer, EnumSet<Ordinate> ordinateFlags) throws IOException, ParseException {
     String nextToken = getNextEmptyOrOpener(tokenizer);
-    if (nextToken.equals(EMPTY)) {
+    if (nextToken.equals(WKTConstants.EMPTY)) {
       return geometryFactory.createGeometryCollection();
     }
-    ArrayList geometries = new ArrayList();
+    List<Geometry> geometries = new ArrayList<Geometry>();
     do {
       Geometry geometry = readGeometryTaggedText(tokenizer);
       geometries.add(geometry);
