@@ -65,7 +65,7 @@ public class WKTWriter
    */
   public static String toPoint(Coordinate p0)
   {
-    return "POINT ( " + format(p0) + " )";
+    return WKTConstants.POINT + " ( " + format(p0) + " )";
   }
 
   /**
@@ -79,9 +79,10 @@ public class WKTWriter
   public static String toLineString(CoordinateSequence seq)
   {
     StringBuilder buf = new StringBuilder();
-    buf.append("LINESTRING ");
+    buf.append(WKTConstants.LINESTRING);
+    buf.append(" ");
     if (seq.size() == 0)
-      buf.append(" EMPTY");
+      buf.append(WKTConstants.EMPTY);
     else {
       buf.append("(");
       for (int i = 0; i < seq.size(); i++) {
@@ -105,9 +106,10 @@ public class WKTWriter
   public static String toLineString(Coordinate[] coord)
   {
     StringBuilder buf = new StringBuilder();
-    buf.append("LINESTRING ");
+    buf.append(WKTConstants.LINESTRING);
+    buf.append(" ");
     if (coord.length == 0)
-      buf.append(" EMPTY");
+      buf.append(WKTConstants.EMPTY);
     else {
       buf.append("(");
       for (int i = 0; i < coord.length; i++) {
@@ -131,7 +133,7 @@ public class WKTWriter
    */
   public static String toLineString(Coordinate p0, Coordinate p1)
   {
-    return "LINESTRING ( " + format(p0) + ", " + format(p1) + " )";
+    return WKTConstants.LINESTRING + " ( " + format(p0) + ", " + format(p1) + " )";
   }
 
   public static String format(Coordinate p) {
@@ -255,10 +257,11 @@ public class WKTWriter
    *   is set to false</b>, the Measure value of coordinates will be written if it is present
    * (i.e. if it is not <code>Double.NaN</code>)</li>
    *   <li>If the specified <b>output dimension is 4</b>, the Z value of coordinates will
-   *   be written even if it is not present when the Measure value is present.The Measrue
+   *   be written even if it is not present when the Measure value is present. The Measure
    *   value of coordinates will be written if it is present
    * (i.e. if it is not <code>Double.NaN</code>)</li>
    * </ul>
+   * See also {@link #setOutputOrdinates(EnumSet)}
    *
    * @param outputDimension the coordinate dimension to output (2 to 4)
    */
@@ -548,7 +551,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    writer.write("POINT ");
+    writer.write(WKTConstants.POINT);
+    writer.write(" ");
     appendOrdinateText(outputOrdinates, writer);
     appendSequenceText(point.getCoordinateSequence(), outputOrdinates, useFormatting,
             level, false, writer, formatter);
@@ -570,7 +574,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    writer.write("LINESTRING ");
+    writer.write(WKTConstants.LINESTRING);
+    writer.write(" ");
     appendOrdinateText(outputOrdinates, writer);
     appendSequenceText(lineString.getCoordinateSequence(), outputOrdinates, useFormatting,
             level, false, writer, formatter);
@@ -592,7 +597,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    writer.write("LINEARRING ");
+    writer.write(WKTConstants.LINEARRING);
+    writer.write(" ");
     appendOrdinateText(outputOrdinates, writer);
     appendSequenceText(linearRing.getCoordinateSequence(), outputOrdinates, useFormatting,
             level, false, writer, formatter);
@@ -614,7 +620,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    writer.write("POLYGON ");
+    writer.write(WKTConstants.POLYGON);
+    writer.write(" ");
     appendOrdinateText(outputOrdinates, writer);
     appendPolygonText(polygon, outputOrdinates, useFormatting,
             level, false, writer, formatter);
@@ -636,7 +643,8 @@ public class WKTWriter
                                           OrdinateFormat formatter)
     throws IOException
   {
-    writer.write("MULTIPOINT ");
+    writer.write(WKTConstants.MULTIPOINT); 
+    writer.write(" ");
     appendOrdinateText(outputOrdinates, writer);
     appendMultiPointText(multipoint, outputOrdinates, useFormatting, level, writer, formatter);
   }
@@ -657,7 +665,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    writer.write("MULTILINESTRING ");
+    writer.write(WKTConstants.MULTILINESTRING);
+    writer.write(" ");
     appendOrdinateText(outputOrdinates, writer);
     appendMultiLineStringText(multiLineString, outputOrdinates, useFormatting,
             level, /*false, */writer, formatter);
@@ -679,7 +688,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    writer.write("MULTIPOLYGON ");
+    writer.write(WKTConstants.MULTIPOLYGON);
+    writer.write(" ");
     appendOrdinateText(outputOrdinates, writer);
     appendMultiPolygonText(multiPolygon, outputOrdinates, useFormatting,
             level, writer, formatter);
@@ -701,7 +711,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    writer.write("GEOMETRYCOLLECTION ");
+    writer.write(WKTConstants.GEOMETRYCOLLECTION);
+    writer.write(" ");
     appendOrdinateText(outputOrdinates, writer);
     appendGeometryCollectionText(geometryCollection, outputOrdinates,
             useFormatting, level, writer, formatter);
@@ -770,9 +781,9 @@ public class WKTWriter
   private void appendOrdinateText(EnumSet<Ordinate> outputOrdinates, Writer writer) throws IOException {
 
     if (outputOrdinates.contains(Ordinate.Z))
-      writer.append('Z');
+      writer.append(WKTConstants.Z);
     if (outputOrdinates.contains(Ordinate.M))
-      writer.append('M');
+      writer.append(WKTConstants.M);
   }
 
   /**
@@ -792,7 +803,7 @@ public class WKTWriter
     throws IOException
   {
     if (seq.size() == 0) {
-      writer.write("EMPTY");
+      writer.write(WKTConstants.EMPTY);
     }
     else {
       if (indentFirst) indent(useFormatting, level, writer);
@@ -829,7 +840,7 @@ public class WKTWriter
     throws IOException
   {
     if (polygon.isEmpty()) {
-      writer.write("EMPTY");
+      writer.write(WKTConstants.EMPTY);
     }
     else {
       if (indentFirst) indent(useFormatting, level, writer);
@@ -860,8 +871,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    if (multiPoint.isEmpty()) {
-      writer.write("EMPTY");
+    if (multiPoint.getNumGeometries() == 0) {
+      writer.write(WKTConstants.EMPTY);
     }
     else {
       writer.write("(");
@@ -893,8 +904,8 @@ public class WKTWriter
            boolean useFormatting, int level, /*boolean indentFirst, */Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    if (multiLineString.isEmpty()) {
-      writer.write("EMPTY");
+    if (multiLineString.getNumGeometries() == 0) {
+      writer.write(WKTConstants.EMPTY);
     }
     else {
       int level2 = level;
@@ -928,8 +939,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    if (multiPolygon.isEmpty()) {
-      writer.write("EMPTY");
+    if (multiPolygon.getNumGeometries() == 0) {
+      writer.write(WKTConstants.EMPTY);
     }
     else {
       int level2 = level;
@@ -963,8 +974,8 @@ public class WKTWriter
           int level, Writer writer, OrdinateFormat formatter)
     throws IOException
   {
-    if (geometryCollection.isEmpty()) {
-      writer.write("EMPTY");
+    if (geometryCollection.getNumGeometries() == 0) {
+      writer.write(WKTConstants.EMPTY);
     }
     else {
       int level2 = level;
