@@ -60,7 +60,8 @@ import org.locationtech.jts.io.WKTWriter;
  * @author Martin Davis
  */
 public class QuadEdgeSubdivision {
-	/**
+
+  /**
 	 * Gets the edges for the triangle to the left of the given {@link QuadEdge}.
 	 * 
 	 * @param startQE
@@ -78,6 +79,8 @@ public class QuadEdgeSubdivision {
 	}
 
 	private final static double EDGE_COINCIDENCE_TOL_FACTOR = 1000;
+	
+  private static final double FRAME_SIZE_FACTOR = 10.0;
 
 	// debugging only - preserve current subdiv statically
 	// private static QuadEdgeSubdivision currentSubdiv;
@@ -114,22 +117,29 @@ public class QuadEdgeSubdivision {
 		locator = new LastFoundQuadEdgeLocator(this);
 	}
 
+	/**
+	 * Creates a triangular frame which contains the vertices to be triangulated.
+	 * <p>
+	 * The frame must be large enough so that its vertices are not in the circumcircle
+	 * of any constructed triangle.  
+	 * This ensures that the vertices of the frame do not prevent the convex hull
+	 * of the input vertices from forming edges of the triangulation.
+	 * This is done by using a heuristic size 
+	 * of the frame.  However, it may be that this is not fully robust, 
+	 * for input points which contain very narry triangles.
+	 * 
+	 * @param env the envelope of the input points
+	 */
 	private void createFrame(Envelope env)
 	{
 		double deltaX = env.getWidth();
 		double deltaY = env.getHeight();
-		double offset = 0.0;
-		if (deltaX > deltaY) {
-			offset = deltaX * 10.0;
-		} else {
-			offset = deltaY * 10.0;
-		}
+		double frameSize = Math.max(deltaX, deltaY) * FRAME_SIZE_FACTOR;
 
-		frameVertex[0] = new Vertex((env.getMaxX() + env.getMinX()) / 2.0, env
-				.getMaxY()
-				+ offset);
-		frameVertex[1] = new Vertex(env.getMinX() - offset, env.getMinY() - offset);
-		frameVertex[2] = new Vertex(env.getMaxX() + offset, env.getMinY() - offset);
+		frameVertex[0] = new Vertex((env.getMaxX() + env.getMinX()) / 2.0, 
+		                              env.getMaxY()	+ frameSize);
+		frameVertex[1] = new Vertex(env.getMinX() - frameSize, env.getMinY() - frameSize);
+		frameVertex[2] = new Vertex(env.getMaxX() + frameSize, env.getMinY() - frameSize);
 
 		frameEnv = new Envelope(frameVertex[0].getCoordinate(), frameVertex[1]
 				.getCoordinate());
@@ -607,6 +617,24 @@ public class QuadEdgeSubdivision {
 		return edges;
 	}
   
+  /**
+   * Gets the edges which touch frame vertices. The returned edges are oriented so
+   * that their origin is a frame vertex.
+   * 
+   * @return the edges which touch the frame
+   */
+  public List<QuadEdge> getFrameEdges() {
+    List<QuadEdge> edges = getPrimaryEdges(true);
+    List<QuadEdge> frameEdges = new ArrayList<QuadEdge>();
+    for (QuadEdge e : edges) {
+      if (isFrameEdge(e)) {
+        QuadEdge fe = isFrameVertex(e.orig()) ? e : e.sym();
+        frameEdges.add(fe);
+      }
+    }
+    return frameEdges;
+  }
+	
   /**
    * A TriangleVisitor which computes and sets the 
    * circumcentre as the origin of the dual 
@@ -727,7 +755,7 @@ public class QuadEdgeSubdivision {
 		private List triList = new ArrayList();
 
 		public void visit(QuadEdge[] triEdges) {
-			triList.add(triEdges);
+			triList.add(new QuadEdge[]{triEdges[0], triEdges[1], triEdges[2]});
 		}
 
 		public List getTriangleEdges() {
@@ -857,6 +885,25 @@ public class QuadEdgeSubdivision {
 		return geomFact.createGeometryCollection(tris);
 	}
 
+	/**
+   * Gets the geometry for the triangles in a triangulated subdivision as a {@link GeometryCollection}
+   * of triangular {@link Polygon}s, optionally including the frame triangles.
+   * 
+ 	 * @param includeFrame true if the frame triangles should be included
+ 	 * @param geomFact the GeometryFactory to use
+   * @return a GeometryCollection of triangular Polygons
+	 */
+  public Geometry getTriangles(boolean includeFrame, GeometryFactory geomFact) {
+    List triPtsList = getTriangleCoordinates(includeFrame);
+    Polygon[] tris = new Polygon[triPtsList.size()];
+    int i = 0;
+    for (Iterator it = triPtsList.iterator(); it.hasNext();) {
+      Coordinate[] triPt = (Coordinate[]) it.next();
+      tris[i++] = geomFact.createPolygon(geomFact.createLinearRing(triPt));
+    }
+    return geomFact.createGeometryCollection(tris);
+  }
+	 
 	/**
 	 * Gets the cells in the Voronoi diagram for this triangulation.
 	 * The cells are returned as a {@link GeometryCollection} of {@link Polygon}s
@@ -947,4 +994,61 @@ public class QuadEdgeSubdivision {
     return cellPoly;
   }
   
+  /**
+   * Tests whether a subdivision is a valid Delaunay Triangulation.
+   * This is the case iff every edge is locally Delaunay, meaning that
+   * the apex of one adjacent triangle is not inside the circumcircle 
+   * of the other adjacent triangle.
+   * 
+   * @return true if the subdivision is Delaunay
+   */
+  public boolean isDelaunay() {
+    List<QuadEdge> edges = getPrimaryEdges(true);
+    for (QuadEdge e : edges) {
+      Vertex a0 = e.oPrev().dest();
+      Vertex a1 = e.oNext().dest();
+      boolean isDelaunay = ! a1.isInCircle(e.orig(), a0, e.dest());
+      if (! isDelaunay) {
+        /*
+        System.out.println(WKTWriter.toLineString(new Coordinate[] {
+            e.orig().getCoordinate(), a0.getCoordinate(), e.dest().getCoordinate()
+        }));
+        */
+        return false;
+      }
+    }
+    return true;
+  }
+  
+  /**
+   * Tests whether the frame edges are Delaunay
+   * @return true if the frame edges are Delaunay
+   */
+  /*
+  public boolean isFrameDelaunay() {
+    List<QuadEdge> edges = getFrameEdges();
+    for (QuadEdge e : edges) {
+      Vertex a0 = e.oPrev().dest();
+      Vertex a1 = e.oNext().dest();
+      boolean isDelaunay = ! a1.isInCircle(e.orig(), a0, e.dest());
+      if (! isDelaunay) {
+
+        return false;
+      }
+    }
+    return true;
+  }
+  
+  public void makeFrameDelaunay() {
+    List<QuadEdge> edges = getFrameEdges();
+    for (QuadEdge e : edges) {
+      Vertex a0 = e.oPrev().dest();
+      Vertex a1 = e.oNext().dest();
+      boolean isDelaunay = ! a1.isInCircle(e.orig(), a0, e.dest());
+      if (! isDelaunay) {
+        QuadEdge.swap(e);
+      }
+    }
+  }
+  */
 }
