@@ -37,6 +37,7 @@ import junit.framework.TestCase;
 public abstract class GeometryTestCase extends TestCase{
 
   private static final String CHECK_EQUAL_FAIL = "FAIL - Expected = %s -- Actual = %s\n";
+  private static final String CHECK_EQUAL_FAIL_MSG = "FAIL - %s: Expected = %s -- Actual = %s\n";
 
   final GeometryFactory geomFactory;
   
@@ -59,6 +60,10 @@ public abstract class GeometryTestCase extends TestCase{
     return geomFactory;
   }
   
+  protected void checkValid(Geometry geom) {
+    assertTrue(geom.isValid());
+  }
+  
   /**
    * Checks that the normalized values of the expected and actual
    * geometries are exactly equal.
@@ -67,11 +72,28 @@ public abstract class GeometryTestCase extends TestCase{
    * @param actual the actual value
    */
   protected void checkEqual(Geometry expected, Geometry actual) {
-    Geometry actualNorm = actual.norm();
-    Geometry expectedNorm = expected.norm();
-    boolean equal = actualNorm.equalsExact(expectedNorm);
+    checkEqual("", expected, actual);
+  }
+
+  /**
+   * Checks that the normalized values of the expected and actual
+   * geometries are exactly equal.
+   * 
+   * @param expected the expected value
+   * @param actual the actual value
+   */
+  protected void checkEqual(String msg, Geometry expected, Geometry actual) {
+    Geometry actualNorm = actual == null ? null : actual.norm();
+    Geometry expectedNorm = expected == null ? null : expected.norm();
+    boolean equal;
+    if (actualNorm == null || expectedNorm == null) {
+      equal = actualNorm == null && expectedNorm == null;
+    }
+    else {
+      equal = actualNorm.equalsExact(expectedNorm);
+    }
     if (! equal) {
-      System.out.format(CHECK_EQUAL_FAIL, expectedNorm, actualNorm );
+      System.out.format(CHECK_EQUAL_FAIL_MSG, msg, expectedNorm, actualNorm );
     }
     assertTrue(equal);
   }
@@ -151,6 +173,13 @@ public abstract class GeometryTestCase extends TestCase{
     return true;
   }
 
+  protected void checkEqual(Geometry[] expected, Geometry[] actual) {
+    assertEquals("Array length", expected.length, actual.length);
+    for (int i = 0; i < expected.length; i++) {
+      checkEqual("element " + i, expected[i], actual[i]);      
+    }
+  }
+
   protected void checkEqual(Collection expected, Collection actual) {
     checkEqual(toGeometryCollection(expected),toGeometryCollection(actual) );
   }
@@ -230,6 +259,14 @@ public abstract class GeometryTestCase extends TestCase{
     return geometries;
   }
 
+  protected Geometry[] readArray(String... wkt) {
+    Geometry[] geometries = new Geometry[wkt.length];
+    for (int i = 0; i < wkt.length; i++) {
+      geometries[i] = (wkt[i] == null) ? null : read(wkt[i]);
+    }
+    return geometries;
+  }
+  
   /**
    * Gets a {@link WKTReader} to read geometries from WKT with expected ordinates.
    *
